@@ -1,4 +1,4 @@
-use crate::MIME;
+use crate::Mime;
 use fnv::FnvHashMap;
 
 #[cfg(not(feature = "with-gpl-data"))]
@@ -18,9 +18,10 @@ fn subclasses() -> &'static str {
     return runtime::subclasses();
 }
 
-pub fn get_aliaslist() -> FnvHashMap<MIME, MIME> {
+pub fn get_aliaslist() -> FnvHashMap<Mime, Mime> {
     aliases()
         .lines()
+        .filter(|line| !line.is_empty())
         .map(|line| {
             let mut parts = line.split_whitespace();
             let a = parts.next().unwrap();
@@ -31,14 +32,15 @@ pub fn get_aliaslist() -> FnvHashMap<MIME, MIME> {
 }
 
 /// Get list of supported MIME types
-pub fn get_supported() -> Vec<MIME> {
-    super::ALLRULES.keys().cloned().collect()
+pub fn get_supported() -> Vec<Mime> {
+    super::ALL_RULES.keys().cloned().collect()
 }
 
 /// Get list of parent -> child subclass links
-pub fn get_subclasses() -> Vec<(MIME, MIME)> {
+pub fn get_subclasses() -> Vec<(Mime, Mime)> {
     subclasses()
         .lines()
+        .filter(|line| !line.is_empty())
         .map(|line| {
             let mut parts = line.split_whitespace();
 
